#!/bin/sh
set -ex

#
# Create or replace database configuration files
#
mkdir -p $FUSEKI_BASE/configuration
cp $CONFIG_TEMPLATES_DIR/config.ttl $FUSEKI_BASE
cp $CONFIG_TEMPLATES_DIR/dalia.ttl $FUSEKI_BASE/configuration
cp $CONFIG_TEMPLATES_DIR/ontologies.ttl $FUSEKI_BASE/configuration

#
# Create "dalia" dataset if it does not already exist, insert RDF data from
# $DALIA_DATA_DIR and build a text index for it.
#
if [ ! -d "$FUSEKI_BASE/databases/dalia" ]; then
  find $DALIA_DATA_DIR \( -iname "*.ttl" -o -iname "*.rdf" -o -iname "*.owl" \) -type f -exec $SCRIPTS_DIR/load.sh $FUSEKI_BASE/configuration/dalia.ttl {} \;
  $SCRIPTS_DIR/textindex.sh $FUSEKI_BASE/configuration/dalia.ttl
fi

#
# (Re-)create "ontologies" dataset, insert RDF data from $ONTOLOGIES_DIR and build
# a text index for it.
#
rm -Rf $FUSEKI_BASE/databases/ontologies
find $ONTOLOGIES_DIR \( -iname "*.ttl" -o -iname "*.rdf" -o -iname "*.owl" -o -iname "*.rdf.gz" \) -type f -exec $SCRIPTS_DIR/load.sh $FUSEKI_BASE/configuration/ontologies.ttl {} \;
$SCRIPTS_DIR/textindex.sh $FUSEKI_BASE/configuration/ontologies.ttl

#
# Make sure the fuseki user owns $FUSEKI_BASE
#
chown -R fuseki:fuseki $FUSEKI_BASE

exec "$@"
